package t::Colourable;

use v5.14;
use warnings;

use Tangence::Constants;

0x55AA;
